﻿//
// Copyright (c) 2017, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.ObjectModel;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.Script.Serialization;

using MindFusion.Charting;
using System.Drawing;
using Brush = MindFusion.Drawing.Brush;
using SolidBrush = MindFusion.Drawing.SolidBrush;
using LinearGradientBrush = MindFusion.Drawing.LinearGradientBrush;


namespace Test
{
	public partial class ListBinding : System.Web.UI.Page
	{
		protected void Page_Init(object sender, EventArgs e)
		{
			// this class demonstrates custom drawing in Canvas mode, see Scripts/CustomNode.js
			radarChart.RegisterCustomType(typeof(StudentData), "StudentData");

			// register converters for serializing .NET items into JSON objects
			radarChart.RegisterConverters(new JavaScriptConverter[] { new StudentDataConverter() });
		}


		protected void Page_Load(object sender, EventArgs e)
		{
			if (!IsPostBack)
			{

				var plot = (RadarPlot)radarChart.Plot;

				// create sample data, a list of .NET objects
				var data = CreateData();
				for (var i = 0; i < 5; i++)
				{
					var axis = new Axis();
					axis.Title = data[i].Subject;
					axis.MinValue = 0;
					axis.MaxValue = 4;
					plot.Axes.Add(axis);
				}

				// set the data source and specify property names to use as data
				radarChart.XDataFields = radarChart.YDataFields = new ObservableCollection<string>() { "GPA1", "GPA2", "GPA3" };
				radarChart.InnerLabelsDataFields = new ObservableCollection<string>() { "GPA1", "GPA2", "GPA3" };
				radarChart.ToolTipsDataFields = new ObservableCollection<string>() { "Subject", "Subject", "Subject" };
				radarChart.DataSource = data;
				radarChart.DataBind();

				// set the series titles
				((DataBoundSeries)radarChart.Series[0]).Title = "age range 7-10";
				((DataBoundSeries)radarChart.Series[1]).Title = "age range 11-13";
				((DataBoundSeries)radarChart.Series[2]).Title = "age range 14-17";

				// set up legend
				radarChart.LegendTitle = "GPA by subject and age";
				radarChart.Theme.LegendBackground = new SolidBrush(Color.Transparent);
				radarChart.AllowMoveLegend = false;

				// customize appearance
				radarChart.ShowCoordinates = false;
				radarChart.Plot.Margin = new Margins(0, 0, 0, 30);
				radarChart.BackColor = ColorTranslator.FromHtml("#ffffff");
				radarChart.GridColor1 = ColorTranslator.FromHtml("#e0e9e9");
				radarChart.GridColor2 = ColorTranslator.FromHtml("#ffffff");
				radarChart.Theme.HighlightStroke = new SolidBrush(ColorTranslator.FromHtml("#9caac6"));
				radarChart.Theme.AxisTitleFontStyle = FontStyle.Underline;
				radarChart.Theme.LegendTitleFontStyle = FontStyle.Underline;
				radarChart.Theme.AxisStroke = new SolidBrush(ColorTranslator.FromHtml("#c0c0c0"));
				radarChart.Theme.CommonSeriesFills = radarChart.Theme.CommonSeriesStrokes = new List<Brush>()
	{
    new SolidBrush(  ColorTranslator.FromHtml("#669acc")),
    new SolidBrush( ColorTranslator.FromHtml("#ce0000")),
    new SolidBrush( ColorTranslator.FromHtml("#000063"))
	};
				radarChart.Theme.UniformSeriesStrokeThickness = 5;
			}

		}

		public List<StudentData> CreateData()
		{
			var data = new List<StudentData>();

			var subjects = new List<string>() { "Math", "Physics", "Chemistry", "Biology", "IT" };
			var gpa1 = new List<double>() { 2.3, 1.7, 2, 4, 3.7 };
			var gpa2 = new List<double>() { 3.3, 2.7, 1.7, 2, 3.3 };
			var gpa3 = new List<double>() { 4, 3.7, 2, 1, 1.3 };

			for (var i = 0; i < 5; i++)
				data.Add(new StudentData(subjects[i], gpa1[i], gpa2[i], gpa3[i]));

			return data;
		}

		protected void chbShowScatter_CheckedChanged(object sender, EventArgs e)
		{
			radarChart.ShowScatter = chbShowScatter.Checked;
		}

		protected void gridType_SelectedIndexChanged(object sender, EventArgs e)
		{
			radarChart.GridType = (RadarGridType)gridType.SelectedIndex;
		}

		protected void radarType_SelectedIndexChanged(object sender, EventArgs e)
		{
			radarChart.RadarType = (RadarType)radarType.SelectedIndex;
		}

		protected void Button1_Click(object sender, EventArgs e)
		{

		}

	}

	public class StudentData
	{
		public StudentData(string subject, double gpa1, double gpa2, double gpa3)
		{
			this.Subject = subject;
			this.GPA1 = gpa1;
			this.GPA2 = gpa2;
			this.GPA3 = gpa3;
		}

		public string Subject;
		public double GPA1;
		public double GPA2;
		public double GPA3;
	}

	public class StudentDataConverter : JavaScriptConverter
	{
		public StudentDataConverter()
		{
		}

		public override IEnumerable<Type> SupportedTypes
		{
			get { return new List<Type>(new Type[] { typeof(StudentData) }); }
		}

		public override object Deserialize(
			IDictionary<string, object> dictionary, Type type, JavaScriptSerializer serializer)
		{
			var subject = dictionary["Subject"].ToString();
			var gpa1 = double.Parse(dictionary["GPA1"].ToString());
			var gpa2 = double.Parse(dictionary["GPA2"].ToString());
			var gpa3 = double.Parse(dictionary["GPA3"].ToString());
			StudentData data = new StudentData(subject, gpa1, gpa2, gpa3);

			return data;
		}

		public override IDictionary<string, object> Serialize(
			object obj, JavaScriptSerializer serializer)
		{
			StudentData data = obj as StudentData;
			if (data != null)
			{
				IDictionary<string, object> json = new Dictionary<string, object>();

				json.Add("Subject", data.Subject);
				json.Add("GPA1", data.GPA1);
				json.Add("GPA2", data.GPA2);
				json.Add("GPA3", data.GPA3);

				return json;
			}

			return null;
		}
	}

}